@@ -64,8 +64,9 @@ def get_latest_ubuntu_lts_ami(ec2_client, arch):
     )
     amis = response['Images']
     # sort to get latest ubuntu version with latest creation date
+
     def sorting_key_func(image):
-        ubuntu_version_number = re.search(r'-([\d\.]+)-'+arch, image['Name']).group(1)
+        ubuntu_version_number = re.search(r'-([\d\.]+)-' + arch, image['Name']).group(1)
         image_creation_date = parse_iso8601(image['CreationDate'])
         return float(ubuntu_version_number), image_creation_date
     amis = sorted(amis, key=sorting_key_func, reverse=True)
@@ -327,6 +328,7 @@ def handle_interrupted_launch():
 
 def main():
     logging.basicConfig(level=logging.INFO, format='[%(asctime)s] %(levelname)s - %(message)s')
+    logging.getLogger('botocore').setLevel(logging.WARNING)
     arg_parser = argparse.ArgumentParser(
         description='Quickly launch an EC2 instance for small tasks. The instance\'s '
                     'lifecycle is tied to the process, enabling easy Ctrl+C instance termination when done.',
@@ -349,24 +351,15 @@ def main():
     arg_parser.add_argument('--non-interactive', action='store_true', dest='non_interactive',
                             help='By default a shell will be opened in the spawned instance, and the '
                                  'instance will be terminated when the shell is closed. To instead '
-                                 'output ec2 metadata as json and then exit, specify '
-                                 '--non-interactive.')
+                                 'output ec2 metadata as json and then exit, specify --non-interactive.')
     arg_parser.add_argument('--show-data-path', action='store_true', help='Print out the path where ec2instance is '
                             'storing local data and configuration.')
-    arg_parser.add_argument('--delete-sandbox', action='store_true', help='Delete the persistent VPC & keypair '
-                            'created by ec2instance.')
     args = arg_parser.parse_args()
 
     if args.show_data_path:
         print(CONFIG_DIR)
         sys.exit(0)
 
-    if args.delete_sandbox:
-        raise NotImplementedError(
-            'Sorry, automatic sandbox deletion is not yet implemented. Please just search \'ec2instance\' in your VPCs'
-            ' list, and \'ec2instance\' in your EC2 keypairs to find the resources to delete.'
-        )
-
     # Load user data
     if not os.path.exists(DEFAULT_USER_DATA_PATH):
         os.makedirs(os.path.dirname(DEFAULT_USER_DATA_PATH), exist_ok=True)
@@ -387,17 +380,13 @@ def main():
     try:
         boto3_session = boto3.session.Session(profile_name=args.profile_name, region_name=args.aws_region)
         ec2_client = boto3_session.client('ec2')
-
-        # Check/provision AWS pre-reqs
-        ami = get_ami(ec2_client, args.ami_identifier, arch=get_arch(args.instance_type))
-        vpc_id = get_vpc(ec2_client)
-        subnet_id = get_subnet(ec2_client, vpc_id)
-        security_group_id = get_security_group(ec2_client, vpc_id)
-        keypair_name, key_path = get_keypair(ec2_client)
+        # Use region-less STS get caller identity API just as a hack to verify boot3 was able to load credentials. This
+        # is important to check so that we can give the right guidance to very inexperienced AWS users.
+        boto3.client('sts').get_caller_identity()
     except botocore.exceptions.NoCredentialsError:
         logging.error(
-            'Unable to locate AWS credentials!\n\n If you\'re not sure what to do, to resolve please follow these '
-            'steps:\n`'
+            'Unable to locate AWS credentials!\n\nIf you\'re not sure what to do, please follow these '
+            'steps to resolve:\n'
             ' - 1.) Install awscli, https://docs.aws.amazon.com/cli/latest/userguide/getting-started-install.html\n'
             ' - 2.) Run `aws configure` and enter in your AWS access key. How to get an AWS access key is not in '
             'scope of this guide.\n'
@@ -411,6 +400,13 @@ def main():
         )
         sys.exit(1)
 
+    # Check/provision AWS pre-reqs
+    ami = get_ami(ec2_client, args.ami_identifier, arch=get_arch(args.instance_type))
+    vpc_id = get_vpc(ec2_client)
+    subnet_id = get_subnet(ec2_client, vpc_id)
+    security_group_id = get_security_group(ec2_client, vpc_id)
+    keypair_name, key_path = get_keypair(ec2_client)
+
     # Launch
     logging.info('Launching instance... (ETA to usability: ~45 seconds)')
     signal.signal(signal.SIGINT, lambda a, b: handle_interrupted_launch())
